"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var common = require("./image-cache-it.common");
var image_cache_it_common_1 = require("./image-cache-it.common");
var imageSrc = require("tns-core-modules/image-source");
var view_1 = require("tns-core-modules/ui/core/view");
var fs = require("tns-core-modules/file-system");
var utils = require("tns-core-modules/utils/utils");
var ImageCacheIt = (function (_super) {
    __extends(ImageCacheIt, _super);
    function ImageCacheIt() {
        var _this = _super.call(this) || this;
        _this.nativeView = UIImageView.new();
        _this.nativeView.contentMode = 1;
        _this.nativeView.clipsToBounds = true;
        return _this;
    }
    ImageCacheIt.prototype.onMeasure = function (widthMeasureSpec, heightMeasureSpec) {
        var nativeView = this.nativeView;
        if (nativeView) {
            var width = view_1.layout.getMeasureSpecSize(widthMeasureSpec);
            var height = view_1.layout.getMeasureSpecSize(heightMeasureSpec);
            this.setMeasuredDimension(width, height);
        }
    };
    ImageCacheIt.prototype.initNativeView = function () {
        var _this = this;
        if (typeof this.imageUri === 'string' && this.imageUri.startsWith('http')) {
            this.isLoading = true;
            this.nativeView.sd_setImageWithURLPlaceholderImageCompleted(this.imageUri, this.placeHolder
                ? imageSrc.fromFileOrResource(this.placeHolder).ios
                : null, function (p1, p2, p3, p4) {
                _this.isLoading = false;
                if (p2 && _this.errorHolder) {
                    var source = imageSrc.fromFileOrResource(_this.errorHolder);
                    _this.nativeView.image = source ? source.ios : null;
                }
            });
        }
        else if (typeof this.imageUri === 'string' &&
            (this.imageUri.startsWith('/') || this.imageUri.startsWith('file'))) {
            var source = imageSrc.fromFileOrResource(this.imageUri);
            this.nativeView.image = source ? source.ios : null;
        }
        else if (typeof this.imageUri === 'string' &&
            this.imageUri.startsWith('~')) {
            var path = fs.knownFolders.currentApp().path;
            var file = fs.path.join(path, this.imageUri.replace('~', ''));
            var source = imageSrc.fromFileOrResource(file);
            this.nativeView.image = source ? source.ios : null;
        }
        else if (typeof this.imageUri === 'object' && this.imageUri.ios) {
            this.nativeView.image = this.imageUri.ios;
        }
        if (this.resize &&
            this.resize !== undefined &&
            this.resize.split(' ').length > 1) {
            this.nativeView.frame.size.width = parseInt(this.resize.split(',')[0]);
            this.nativeView.frame.size.height = parseInt(this.resize.split(',')[1]);
        }
    };
    ImageCacheIt.prototype[common.imageUriProperty.getDefault] = function () {
        return undefined;
    };
    ImageCacheIt.prototype[common.imageUriProperty.setNative] = function (src) {
        var _this = this;
        if (!src)
            return src;
        if (typeof src === 'string' && src.startsWith('http')) {
            this.isLoading = true;
            this.nativeView.sd_setImageWithURLPlaceholderImageCompleted(src, this.placeHolder
                ? imageSrc.fromFileOrResource(this.placeHolder).ios
                : null, function (p1, p2, p3, p4) {
                _this.isLoading = false;
                if (p2 && _this.errorHolder) {
                    var source = imageSrc.fromFileOrResource(_this.errorHolder);
                    _this.nativeView.image = source ? source.ios : null;
                }
            });
        }
        else if (typeof src === 'string' &&
            (src.startsWith('/') || src.startsWith('file'))) {
            var source = imageSrc.fromFileOrResource(src);
            this.nativeView.image = source ? source.ios : null;
        }
        else if (typeof src === 'object' && src.ios) {
            this.nativeView.image = src.ios;
        }
        else if (typeof this.imageUri === 'string' &&
            this.imageUri.startsWith('~')) {
            var path = fs.knownFolders.currentApp().path;
            var file = fs.path.join(path, this.imageUri.replace('~', ''));
            var source = imageSrc.fromFileOrResource(file);
            this.nativeView.image = source ? source.ios : null;
        }
        else if (typeof this.imageUri === 'object' && this.imageUri.ios) {
            this.nativeView.image = this.imageUri.ios;
        }
        return src;
    };
    ImageCacheIt.prototype[common.resizeProperty.setNative] = function (resize) {
        if (!this.nativeView)
            return resize;
        if (this.resize &&
            this.resize !== undefined &&
            this.resize.split(',').length > 1) {
            this.nativeView.frame.size.width = parseInt(this.resize.split(' ')[0]);
            this.nativeView.frame.size.height = parseInt(this.resize.split(' ')[1]);
        }
        return resize;
    };
    ImageCacheIt.prototype[common.stretchProperty.getDefault] = function () {
        return 'aspectFit';
    };
    ImageCacheIt.prototype[common.stretchProperty.setNative] = function (value) {
        if (!this.nativeView)
            return value;
        switch (value) {
            case 'aspectFit':
                this.nativeView.contentMode = 1;
                break;
            case 'aspectFill':
                this.nativeView.contentMode = 2;
                break;
            case 'fill':
                this.nativeView.contentMode = 0;
                break;
            case 'none':
            default:
                this.nativeView.contentMode = 9;
                break;
        }
        return value;
    };
    ImageCacheIt.getItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = utils.ios.getter(SDWebImageManager, SDWebImageManager.sharedManager);
            if (manager) {
                if (src && src.indexOf('http') > -1) {
                    var url = NSURL.alloc().initWithString(src);
                    manager.loadImageWithURLOptionsProgressCompleted(url, SDWebImageOptions.scaleDownLargeImages, function (receivedSize, expectedSize, path) {
                    }, function (image, data, error, type, finished, completedUrl) {
                        if (image === null && error !== null && data === null) {
                            reject(error.localizedDescription);
                        }
                        else if (finished && completedUrl != null) {
                            if (type == SDImageCacheType.disk) {
                                var key = manager.cacheKeyForURL(completedUrl);
                                var source = manager.imageCache.defaultCachePathForKey(key);
                                resolve(source);
                            }
                            else {
                                var sharedCache = utils.ios.getter(SDImageCache, SDImageCache.sharedImageCache);
                                sharedCache.storeImageForKeyCompletion(image, completedUrl.absoluteString, function () {
                                    var key = manager.cacheKeyForURL(completedUrl);
                                    var source = manager.imageCache.defaultCachePathForKey(key);
                                    resolve(source);
                                });
                            }
                        }
                        else {
                            reject();
                        }
                    });
                }
            }
            else {
                reject();
            }
        });
    };
    ImageCacheIt.deleteItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = utils.ios.getter(SDWebImageManager, SDWebImageManager.sharedManager);
            if (manager) {
                manager.imageCache.removeImageForKeyFromDiskWithCompletion(src, true, function () {
                    resolve();
                });
            }
            else {
                reject();
            }
        });
    };
    ImageCacheIt.fetchItem = function (src) {
        return new Promise(function (resolve, reject) {
            var manager = utils.ios.getter(SDWebImageManager, SDWebImageManager.sharedManager);
            if (manager) {
                if (src && src.indexOf('http') > -1) {
                    var nativeSrc = NSURL.alloc().initWithString(src);
                    manager.loadImageWithURLOptionsProgressCompleted(nativeSrc, SDWebImageOptions.scaleDownLargeImages, function (receivedSize, expectedSize, path) {
                    }, function (image, data, error, type, finished, completedUrl) {
                        if (image === null && error !== null && data === null) {
                            reject(error.localizedDescription);
                        }
                        else if (finished && completedUrl != null) {
                            if (type === SDImageCacheType.disk) {
                                var key = manager.cacheKeyForURL(completedUrl);
                                var source = manager.imageCache.defaultCachePathForKey(key);
                                resolve(source);
                            }
                            else {
                                var sharedCache = utils.ios.getter(SDImageCache, SDImageCache.sharedImageCache);
                                sharedCache.storeImageForKeyCompletion(image, completedUrl.absoluteString, function () {
                                    var key = manager.cacheKeyForURL(completedUrl);
                                    var source = manager.imageCache.defaultCachePathForKey(key);
                                    resolve(source);
                                });
                            }
                        }
                    });
                }
            }
            else {
                reject();
            }
        });
    };
    return ImageCacheIt;
}(image_cache_it_common_1.ImageCacheItBase));
exports.ImageCacheIt = ImageCacheIt;
//# sourceMappingURL=image-cache-it.ios.js.map